pub fn process_response(
response: &Value,
config: Option<&ResponseConfig>,
) -> Result<Value, ResponseError>Expand description
Extract and format a response based on the tool’s response config.
pub fn process_response(
response: &Value,
config: Option<&ResponseConfig>,
) -> Result<Value, ResponseError>Extract and format a response based on the tool’s response config.