mlock

Function mlock 

pub fn mlock(ptr: *const u8, len: usize) -> Result<(), String>
Lock a memory region to prevent it from being swapped to disk. Returns Ok(()) on success, Err with a warning message on failure.