Module sealed_file

Module sealed_file 

Enums

SealedFileError

Constants

DEFAULT_KEY_PATH
Default path for the session key sealed file

Functions

read_and_delete_key
Read the session key from a sealed file, then immediately delete the file.
read_and_delete_key_from
Read session key from a specific path, then delete the file.