Enums
Constants
- DEFAULT_
KEY_ PATH - Default path for the session key sealed file
Functions
- read_
and_ delete_ key - Read the session key from a sealed file, then immediately delete the file.
- read_
and_ delete_ key_ from - Read session key from a specific path, then delete the file.